@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-import cli
+from deploybot.scripts import cli
 from unittest import TestCase
 from click.testing import CliRunner
 
@@ -12,6 +12,6 @@ class TestCli(TestCase):
         self.runner = CliRunner()
 
     def test_cli(self):
-        result = self.runner.invoke(cli, ['help'])
+        result = self.runner.invoke(cli.main(), ['help'])
 
         assert result.exit_code == -1
